@@ -30,16 +30,16 @@ options:
     description:
       - The resource group name to use or create to host the deployed template
     required: true
+    aliases:
+      - resource_group
   location:
     description:
       - The geo-locations in which the resource group will be located.
-    required: false
     default: westus
   deployment_mode:
     description:
       - In incremental mode, resources are deployed without deleting existing resources that are not included in the template.
         In complete mode resources are deployed and existing resources in the resource group not included in the template are deleted.
-    required: false
     default: incremental
     choices:
         - complete
@@ -49,7 +49,6 @@ options:
       - If state is "present", template will be created. If state is "present" and if deployment exists, it will be
         updated. If state is "absent", stack will be removed.
     default: present
-    required: false
     choices:
         - present
         - absent
@@ -57,26 +56,20 @@ options:
     description:
       - A hash containing the templates inline. This parameter is mutually exclusive with 'template_link'.
         Either one of them is required if "state" parameter is "present".
-    required: false
-    default: null
+    type: dict
   template_link:
     description:
       - Uri of file containing the template body. This parameter is mutually exclusive with 'template'. Either one
         of them is required if "state" parameter is "present".
-    required: false
-    default: null
   parameters:
     description:
       - A hash of all the required template variables for the deployment template. This parameter is mutually exclusive
         with 'parameters_link'. Either one of them is required if "state" parameter is "present".
-    required: false
-    default: null
+    type: dict
   parameters_link:
     description:
       - Uri of file containing the parameters body. This parameter is mutually exclusive with 'parameters'. Either
         one of them is required if "state" parameter is "present".
-    required: false
-    default: null
   deployment_name:
     description:
       - The name of the deployment to be tracked in the resource group deployment history. Re-using a deployment name
@@ -85,8 +78,8 @@ options:
   wait_for_deployment_completion:
     description:
       - Whether or not to block until the deployment has completed.
-    default: yes
-    choices: ['yes', 'no']
+    type: bool
+    default: 'yes'
   wait_for_deployment_polling_period:
     description:
       - Time (in seconds) to wait between polls when waiting for deployment completion.
@@ -94,6 +87,7 @@ options:
 
 extends_documentation_fragment:
     - azure
+    - azure_tags
 
 author:
     - David Justice (@devigned)
@@ -422,6 +416,7 @@ class AzureRMDeploymentManager(AzureRMModuleBase):
         self.wait_for_deployment_completion = None
         self.wait_for_deployment_polling_period = None
         self.tags = None
+        self.append_tags = None
 
         self.results = dict(
             deployment=dict(),
@@ -435,7 +430,7 @@ class AzureRMDeploymentManager(AzureRMModuleBase):
 
     def exec_module(self, **kwargs):
 
-        for key in list(self.module_arg_spec.keys()) + ['tags']:
+        for key in list(self.module_arg_spec.keys()) + ['append_tags', 'tags']:
             setattr(self, key, kwargs[key])
 
         if self.state == 'present':
@@ -460,10 +455,14 @@ class AzureRMDeploymentManager(AzureRMModuleBase):
             self.results['changed'] = True
             self.results['msg'] = 'deployment succeeded'
         else:
-            if self.resource_group_exists(self.resource_group_name):
-                self.destroy_resource_group()
-                self.results['changed'] = True
-                self.results['msg'] = "deployment deleted"
+            try:
+                if self.get_resource_group(self.resource_group_name):
+                    self.destroy_resource_group()
+                    self.results['changed'] = True
+                    self.results['msg'] = "deployment deleted"
+            except CloudError:
+                # resource group does not exist
+                pass
 
         return self.results
 
@@ -490,6 +489,16 @@ class AzureRMDeploymentManager(AzureRMModuleBase):
                 uri=self.template_link
             )
 
+        if self.append_tags and self.tags:
+            try:
+                # fetch the RG directly (instead of using the base helper) since we don't want to exit if it's missing
+                rg = self.rm_client.resource_groups.get(self.resource_group_name)
+                if rg.tags:
+                    self.tags = dict(self.tags, **rg.tags)
+            except CloudError:
+                # resource group does not exist
+                pass
+
         params = self.rm_models.ResourceGroup(location=self.location, tags=self.tags)
 
         try:
@@ -537,19 +546,6 @@ class AzureRMDeploymentManager(AzureRMModuleBase):
                 self.fail("Delete resource group and deploy failed with status code: %s and message: %s" %
                           (e.status_code, e.message))
 
-    def resource_group_exists(self, resource_group):
-        '''
-        Return True/False based on existence of requested resource group.
-
-        :param resource_group: string. Name of a resource group.
-        :return: boolean
-        '''
-        try:
-            self.rm_client.resource_groups.get(resource_group)
-        except CloudError:
-            return False
-        return True
-
     def _get_failed_nested_operations(self, current_operations):
         new_operations = []
         for operation in current_operations:
