@@ -42,7 +42,7 @@ class ValidateModulesTest(SanitySingleVersion):
         """
         :type args: SanityConfig
         :type targets: SanityTargets
-        :rtype: SanityResult
+        :rtype: TestResult
         """
         with open(VALIDATE_SKIP_PATH, 'r') as skip_fd:
             skip_paths = skip_fd.read().splitlines()
@@ -57,7 +57,7 @@ class ValidateModulesTest(SanitySingleVersion):
             return SanitySkipped(self.name)
 
         cmd = [
-            'python%s' % args.python_version,
+            args.python_executable,
             'test/sanity/validate-modules/validate-modules',
             '--format', 'json',
             '--arg-spec',
