@@ -16,10 +16,41 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from voluptuous import PREVENT_EXTRA, Any, Required, Schema, Self
+from voluptuous import PREVENT_EXTRA, All, Any, Length, Required, Schema, Self
 from ansible.module_utils.six import string_types
 list_string_types = list(string_types)
 
+
+def sequence_of_sequences(min=None, max=None):
+    return All(
+        Any(
+            None,
+            [Length(min=min, max=max)],
+            tuple([Length(min=min, max=max)]),
+        ),
+        Any(
+            None,
+            [Any(list, tuple)],
+            tuple([Any(list, tuple)]),
+        ),
+    )
+
+
+ansible_module_kwargs_schema = Schema(
+    {
+        'argument_spec': dict,
+        'bypass_checks': bool,
+        'no_log': bool,
+        'check_invalid_arguments': Any(None, bool),
+        'mutually_exclusive': sequence_of_sequences(min=2),
+        'required_together': sequence_of_sequences(min=2),
+        'required_one_of': sequence_of_sequences(min=2),
+        'add_file_common_args': bool,
+        'supports_check_mode': bool,
+        'required_if': sequence_of_sequences(min=3),
+    }
+)
+
 suboption_schema = Schema(
     {
         Required('description'): Any(list_string_types, *string_types),
@@ -50,7 +81,7 @@ option_schema = Schema(
         'default': Any(None, float, int, bool, list, dict, *string_types),
         'suboptions': Any(None, *list_dict_suboption_schema),
         # Note: Types are strings, not literal bools, such as True or False
-        'type': Any(None, "bool")
+        'type': Any(None, 'str', 'list', 'dict', 'bool', 'int', 'float', 'path', 'raw', 'jsonarg', 'json', 'bytes', 'bits')
     },
     extra=PREVENT_EXTRA
 )
